Module types

Module types 

Re-exports

pub use hierarchy::page;

Modules

hierarchy
General-purpose data structures that are built from the basic object types described in 7.3, “Objects” and used throughout PDF technology. This subclause describes data structures for text strings, dates, rectangles, name trees, and number trees.
pdf_writer
Implementation of the PdfWriter wrapper.